==> haskell-stm-chans-3.0.0.4-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-chans
version:              3.0.0.4
visibility:           public
id:                   stm-chans-3.0.0.4-1AySdkFWV5p7rvzfM3Fr0x
key:                  stm-chans-3.0.0.4-1AySdkFWV5p7rvzfM3Fr0x
license:              BSD-3-Clause
copyright:            Copyright (c) 2011--2015 wren gayle romano
maintainer:           wren@community.haskell.org
author:               wren gayle romano, Thomas DuBuisson
stability:            provisional
homepage:             http://code.haskell.org/~wren/
synopsis:             Additional types of channels for STM.
description:          Additional types of channels for STM.
category:             Concurrency
abi:                  daae5d22236bfeb41ebc9b05836212f4
exposed:              True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue

import-dirs:          /usr/lib/ghc-8.10.1/site-local/stm-chans-3.0.0.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/stm-chans-3.0.0.4
hs-libraries:         HSstm-chans-3.0.0.4-1AySdkFWV5p7rvzfM3Fr0x
depends:              base-4.14.0.0 stm-2.5.0.0
haddock-interfaces:   /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html:         /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-chans-3.0.0.4-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-chans
version:              3.0.0.4
visibility:           public
id:                   stm-chans-3.0.0.4-IkLPF4Ira3LYY9IzoULtB
key:                  stm-chans-3.0.0.4-IkLPF4Ira3LYY9IzoULtB
license:              BSD-3-Clause
copyright:            Copyright (c) 2011--2015 wren gayle romano
maintainer:           wren@community.haskell.org
author:               wren gayle romano, Thomas DuBuisson
stability:            provisional
homepage:             http://code.haskell.org/~wren/
synopsis:             Additional types of channels for STM.
description:          Additional types of channels for STM.
category:             Concurrency
abi:                  8676db1ad36334e4393c56155fdd0197
exposed:              True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue

import-dirs:          /usr/lib/ghc-8.10.2/site-local/stm-chans-3.0.0.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/stm-chans-3.0.0.4
hs-libraries:         HSstm-chans-3.0.0.4-IkLPF4Ira3LYY9IzoULtB
depends:              base-4.14.1.0 stm-2.5.0.0
haddock-interfaces:   /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html:         /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
